exttypes Package
================

:mod:`exttypes` Package
-----------------------

.. automodule:: numba.exttypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`attributetable` Module
----------------------------

.. automodule:: numba.exttypes.attributetable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`autojitclass` Module
--------------------------

.. automodule:: numba.exttypes.autojitclass
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`autojitmeta` Module
-------------------------

.. automodule:: numba.exttypes.autojitmeta
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`compileclass` Module
--------------------------

.. automodule:: numba.exttypes.compileclass
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`entrypoints` Module
-------------------------

.. automodule:: numba.exttypes.entrypoints
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`jitclass` Module
----------------------

.. automodule:: numba.exttypes.jitclass
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`methodtable` Module
-------------------------

.. automodule:: numba.exttypes.methodtable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ordering` Module
----------------------

.. automodule:: numba.exttypes.ordering
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`signatures` Module
------------------------

.. automodule:: numba.exttypes.signatures
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: numba.exttypes.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`validators` Module
------------------------

.. automodule:: numba.exttypes.validators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`variable` Module
----------------------

.. automodule:: numba.exttypes.variable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`virtual` Module
---------------------

.. automodule:: numba.exttypes.virtual
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.exttypes.tests
    numba.exttypes.types

